Package: DenoIST
Title: DenoIST: Denoising Image-based Spatial Transcriptomics data
Version: 1.1.0
Authors@R: c( 
    person("Aaron", "Kwok", , "akwok@svi.edu.au", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-7831-4198")),
    person("Heejung","Shim", role=c("aut")),
    person("Davis","McCarthy", role=c("aut")))
biocViews: Software, Preprocessing, Spatial, GeneExpression,
        SingleCell, Transcriptomics
Description: DenoIST identifies and removes contamination in Image-based Spatial Transcriptomics data, using a transposed poisson mixture model with local neighbourhood offsets to infer genes that are likely to be due to neighbourhood contamination rather than endogenous expression.
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
URL: https://github.com/aaronkwc/DenoIST
BugReports: https://github.com/aaronkwc/DenoIST/issues
Imports: flexmix, hexbin, pbapply, sparseMatrixStats,
        SpatialExperiment, stats, SummarizedExperiment, parallel,
        Matrix, dbscan, methods
Suggests: BiocStyle, knitr, rmarkdown, testthat, ggplot2, patchwork
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/DenoIST
git_branch: devel
git_last_commit: 35bfd0d
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:21:12 UTC; biocbuild
Author: Aaron Kwok [aut, cre] (ORCID: <https://orcid.org/0000-0001-7831-4198>),
  Heejung Shim [aut],
  Davis McCarthy [aut]
Maintainer: Aaron Kwok <akwok@svi.edu.au>
Depends: R (>= 3.5.0)
