# Generated by roxygen2: do not edit by hand

export(denoist)
export(local_offset_distance_with_background)
export(local_offset_distance_with_background_fast)
export(solve_poisson_mixture)
importFrom(Matrix,sparseMatrix)
importFrom(SpatialExperiment,spatialCoords)
importFrom(SummarizedExperiment,assay)
importFrom(dbscan,frNN)
importFrom(flexmix,FLXMRglm)
importFrom(flexmix,clusters)
importFrom(flexmix,flexmix)
importFrom(flexmix,parameters)
importFrom(hexbin,hexbin)
importFrom(methods,as)
importFrom(parallel,clusterExport)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(pbapply,pblapply)
importFrom(sparseMatrixStats,rowSums2)
importFrom(stats,dpois)
importFrom(stats,runif)
importFrom(stats,xtabs)
